<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
<context>
    <name>App.About</name>
    <message>
        <source>System Monitor</source>
        <translation>Mbikëqyrës Sistemi</translation>
    </message>
    <message>
        <source>System Monitor is a tool to monitor realtime system load, view and control processes and services running on your system.</source>
        <translation>Mbikëqyrësi i Sistemit është një mjet për të mbikëqyrur në kohë reale ngarkesën e sistemit, për të parë dhe kontrolluar procese dhe shërbime që xhirojnë në sistemin tuaj.</translation>
    </message>
</context>
<context>
    <name>BaseDetailViewWidget</name>
    <message>
        <source>Hide details</source>
        <translation>Fshihi hollësitë</translation>
    </message>
    <message>
        <source>Overall utilization</source>
        <translation>Përdorim i përgjithshëm</translation>
    </message>
    <message>
        <source>Individual utilization</source>
        <translation>Përdorim individual</translation>
    </message>
</context>
<context>
    <name>BlockDevItemWidget</name>
    <message>
        <source>Read</source>
        <translation>Lexim</translation>
    </message>
    <message>
        <source>Write</source>
        <translation>Shkrim</translation>
    </message>
</context>
<context>
    <name>CPUDetailGrapTableItem</name>
    <message>
        <source>60 seconds</source>
        <translation>60 sekonda</translation>
    </message>
</context>
<context>
    <name>CPUInfoModel</name>
    <message>
        <source>%1 days %2 hours %3 minutes</source>
        <translation>%1 ditë %2 orë %3 minuta</translation>
    </message>
</context>
<context>
    <name>CPUSummaryTableModel</name>
    <message>
        <source>Utilization</source>
        <translation>Përdorim</translation>
    </message>
    <message>
        <source>Current frequency</source>
        <translation>Frekuenca e tanishme</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>Frekuencë</translation>
    </message>
    <message>
        <source>Sockets</source>
        <translation>Socket-e</translation>
    </message>
    <message>
        <source>Logical processors</source>
        <translation>Procesorë logjikë</translation>
    </message>
    <message>
        <source>Virtualization</source>
        <translation>Virtualizim</translation>
    </message>
    <message>
        <source>L1i cache</source>
        <translation>Fshehtinë L1i</translation>
    </message>
    <message>
        <source>L1d cache</source>
        <translation>Fshehtinë L1d</translation>
    </message>
    <message>
        <source>L2 cache</source>
        <translation>Fshehtinë L2</translation>
    </message>
    <message>
        <source>L3 cache</source>
        <translation>Fshehtinë L3</translation>
    </message>
    <message>
        <source>Load average</source>
        <translation>Mesatare ngarkese</translation>
    </message>
    <message>
        <source>File descriptors</source>
        <translation>Përshkrues kartelash</translation>
    </message>
    <message>
        <source>Processes</source>
        <translation>Procese</translation>
    </message>
    <message>
        <source>Threads</source>
        <translation>Rrjedha</translation>
    </message>
    <message>
        <source>Host name</source>
        <translation>Emër strehe</translation>
    </message>
    <message>
        <source>OS type</source>
        <translation>Lloj OS-i</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <source>Up time</source>
        <translation>Kohë në punë</translation>
    </message>
</context>
<context>
    <name>ChartViewWidget</name>
    <message>
        <source>60 seconds</source>
        <translation>60 sekonda</translation>
    </message>
</context>
<context>
    <name>Common.Search</name>
    <message>
        <source>No search results</source>
        <translation>S’ka përfundime kërkimi</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>Hollësi</translation>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>Hollësi</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Active.State</name>
    <message>
        <source>active</source>
        <translation>aktiv</translation>
    </message>
    <message>
        <source>reloading</source>
        <translation>po ringarkohet</translation>
    </message>
    <message>
        <source>inactive</source>
        <translation>jo aktiv</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>i dështuar</translation>
    </message>
    <message>
        <source>activating</source>
        <translation>po aktivizohet</translation>
    </message>
    <message>
        <source>deactivating</source>
        <translation>po çaktivizohet</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Load.State</name>
    <message>
        <source>stub</source>
        <translation>stub</translation>
    </message>
    <message>
        <source>not-found</source>
        <translation>s’u gjet</translation>
    </message>
    <message>
        <source>bad-setting</source>
        <translation>parametër i gabuar</translation>
    </message>
    <message>
        <source>error</source>
        <translation>gabim</translation>
    </message>
    <message>
        <source>merged</source>
        <translation>përdorur</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>i maskuar</translation>
    </message>
    <message>
        <source>loaded</source>
        <translation>i ngarkuar</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Startup.Mode</name>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Dorazi</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.State</name>
    <message>
        <source>enabled</source>
        <translation>i aktivizuar</translation>
    </message>
    <message>
        <source>disabled</source>
        <translation>i çaktivizuar</translation>
    </message>
    <message>
        <source>static</source>
        <translation>statik</translation>
    </message>
    <message>
        <source>transient</source>
        <translation>tranzient</translation>
    </message>
    <message>
        <source>indirect</source>
        <translation>i tërthortë</translation>
    </message>
    <message>
        <source>enabled-runtime</source>
        <translation>aktualizuar-dyndimë</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>i maskuar</translation>
    </message>
    <message>
        <source>generated</source>
        <translation>prodhuar</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Sub.State</name>
    <message>
        <source>dead</source>
        <translation>i vdekur</translation>
    </message>
    <message>
        <source>start-pre</source>
        <translation>përpara-lëshjes</translation>
    </message>
    <message>
        <source>start</source>
        <translation>nise</translation>
    </message>
    <message>
        <source>start-post</source>
        <translation>përfundimtare-lëshjes</translation>
    </message>
    <message>
        <source>running</source>
        <translation>xhiron</translation>
    </message>
    <message>
        <source>exited</source>
        <translation>i iku</translation>
    </message>
    <message>
        <source>reload</source>
        <translation>ringarkoje</translation>
    </message>
    <message>
        <source>stop</source>
        <translation>ndale</translation>
    </message>
    <message>
        <source>stop-watchdog</source>
        <translation>stop-watchdog</translation>
    </message>
    <message>
        <source>stop-sigterm</source>
        <translation>stop-sigterm</translation>
    </message>
    <message>
        <source>stop-sigkill</source>
        <translation>stop-sigkill</translation>
    </message>
    <message>
        <source>stop-post</source>
        <translation>përfundimtare-stop</translation>
    </message>
    <message>
        <source>final-sigterm</source>
        <translation>final-sigterm</translation>
    </message>
    <message>
        <source>final-sigkill</source>
        <translation>final-sigkill</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>i dështuar</translation>
    </message>
    <message>
        <source>auto-restart</source>
        <translation>vetërinisu</translation>
    </message>
</context>
<context>
    <name>DBusAlarmNotify</name>
    <message>
        <source>Warning</source>
        <translation>Kujdes</translation>
    </message>
    <message>
        <source>Your CPU usage is higher than %1%!</source>
        <translation>Përdorimi juaj i CPU-së është më lart se %1%!</translation>
    </message>
    <message>
        <source>Your memory usage is higher than %1%!</source>
        <translation>Përdorimi juaj i kujtesës është më lart se %1%!</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Shiheni</translation>
    </message>
</context>
<context>
    <name>DeailTableModel</name>
    <message>
        <source>Used</source>
        <translation>Të përdorura</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Të lira</translation>
    </message>
    <message>
        <source>Shared</source>
        <translation>Jukshtuar</translation>
    </message>
    <message>
        <source>Cached</source>
        <translation>Shpenzuar</translation>
    </message>
    <message>
        <source>Buffers</source>
        <translation>Buffëra</translation>
    </message>
    <message>
        <source>Cached swap</source>
        <translation>Shpenzim shpenzuar</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktiv</translation>
    </message>
    <message>
        <source>Inactive</source>
        <translation>Jo aktiv</translation>
    </message>
    <message>
        <source>Dirty</source>
        <translation>Zëra</translation>
    </message>
    <message>
        <source>Mapped</source>
        <translation>Mapuar</translation>
    </message>
    <message>
        <source>Total swap</source>
        <translation>Swap gjithsej</translation>
    </message>
    <message>
        <source>Free swap</source>
        <translation>Swap i lirë</translation>
    </message>
    <message>
        <source>Slab</source>
        <translation>Slab</translation>
    </message>
</context>
<context>
    <name>DeailTableModelBlock</name>
    <message>
        <source>Model</source>
        <translation>Model</translation>
    </message>
    <message>
        <source>Read speed</source>
        <translation>Shpejtësi leximesh</translation>
    </message>
    <message>
        <source>Write speed</source>
        <translation>Shpejtësi shkrimesh</translation>
    </message>
    <message>
        <source>Capacity</source>
        <translation>Kapacitet</translation>
    </message>
    <message>
        <source>Sectors read</source>
        <translation>Sektorë të lexuar</translation>
    </message>
    <message>
        <source>Reads/s</source>
        <translation>Lexime/s</translation>
    </message>
    <message>
        <source>Sectors read/s</source>
        <translation>Sektorë të lexuar/s</translation>
    </message>
    <message>
        <source>Reads merged/s</source>
        <translation>Lidhjejë e kuptuar/s</translation>
    </message>
    <message>
        <source>Sectors written</source>
        <translation>Sektorë të shkruar</translation>
    </message>
    <message>
        <source>Writes completed </source>
        <translation>Shkruar i përfunduar</translation>
    </message>
    <message>
        <source>Writes merged</source>
        <translation>Shkrimet lidhura</translation>
    </message>
    <message>
        <source>Writes/s</source>
        <translation>Shkrime/s</translation>
    </message>
    <message>
        <source>Sectors written/s</source>
        <translation>Sektorë të shkruar/s</translation>
    </message>
    <message>
        <source>Writes merged/s</source>
        <translation>Shkrimet lidhura/s</translation>
    </message>
</context>
<context>
    <name>Error.Dialog</name>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Help.Shortcut.System</name>
    <message>
        <source>System</source>
        <translation>Sistem</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Shfaq shkurtore</translation>
    </message>
</context>
<context>
    <name>Kill.Process.Dialog</name>
    <message>
        <source>Ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Përfundimi i këtij procesi mund të shkaktojë humbje të dhënash.
Jeni i sigurt se doni të vazhdohet?</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>Përfundoje procesin</translation>
    </message>
    <message>
        <source>Force ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Përfundimi me zor i këtij procesi mund të shkaktojë humbje të dhënash.
Jeni i sigurt se doni të vazhdohet?</translation>
    </message>
    <message>
        <source>Force ending this application may cause data loss.
Are you sure you want to continue?</source>
        <translation>Përfundimi me zor i këtij aplikacioni mund të shkaktojë humbje të dhënash.
Jeni i sigurt se doni të vazhdohet?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuloje</translation>
    </message>
    <message>
        <source>Force End</source>
        <comment>button</comment>
        <translation>Detyro Përfundim</translation>
    </message>
    <message>
        <source>End</source>
        <comment>button</comment>
        <translation>Përfundoje</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Settings</source>
        <translation>Rregullime</translation>
    </message>
</context>
<context>
    <name>MemStatViewWidget</name>
    <message>
        <source>Size</source>
        <translation>Madhësi</translation>
    </message>
</context>
<context>
    <name>NetInfoDetailItemDelegate</name>
    <message>
        <source>IP address:</source>
        <translation>Adresë IP:</translation>
    </message>
    <message>
        <source>Netmask:</source>
        <translation>Netmask-ë:</translation>
    </message>
    <message>
        <source>Broadcast:</source>
        <translation>Transmisioni i publikë:</translation>
    </message>
    <message>
        <source>Prefixlen:</source>
        <translation>Prefixlen:</translation>
    </message>
    <message>
        <source>Scope:</source>
        <translation>Krahësia:</translation>
    </message>
</context>
<context>
    <name>NetInfoModel</name>
    <message>
        <source>Connection type</source>
        <translation>Lloj lidhjeje</translation>
    </message>
    <message>
        <source>ESSID</source>
        <translation>ESSID</translation>
    </message>
    <message>
        <source>Link quality</source>
        <translation>Cilësi lidhjeje</translation>
    </message>
    <message>
        <source>Signal strength</source>
        <translation>Fortësi sinjali</translation>
    </message>
    <message>
        <source>Noise level</source>
        <translation>Nivel zhurmash</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>Bandwidth</source>
        <translation>Kohësia</translation>
    </message>
    <message>
        <source>RX packets</source>
        <translation>Paketa RX</translation>
    </message>
    <message>
        <source>RX bytes</source>
        <translation>Bajte RX</translation>
    </message>
    <message>
        <source>RX errors</source>
        <translation>Gabime RX</translation>
    </message>
    <message>
        <source>RX dropped</source>
        <translation>RX të humbur</translation>
    </message>
    <message>
        <source>RX overruns</source>
        <translation>RX overruns</translation>
    </message>
    <message>
        <source>RX frame</source>
        <translation>RAM frame</translation>
    </message>
    <message>
        <source>TX packets</source>
        <translation>Paketa TX</translation>
    </message>
    <message>
        <source>TX bytes</source>
        <translation>Bajte TX</translation>
    </message>
    <message>
        <source>TX errors</source>
        <translation>Gabime TX</translation>
    </message>
    <message>
        <source>TX overruns</source>
        <translation>TX overruns</translation>
    </message>
    <message>
        <source>TX carrier</source>
        <translation>Operator TX</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>TX dropped</source>
        <translation>TX dropped</translation>
    </message>
</context>
<context>
    <name>Process.Attributes.Dialog</name>
    <message>
        <source>Command line</source>
        <translation>Rresht urdhrash</translation>
    </message>
    <message>
        <source>Start time</source>
        <translation>Kohë fillimi</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Emër</translation>
    </message>
</context>
<context>
    <name>Process.Choose.Window.Dialog</name>
    <message>
        <source>Click the application you want to end</source>
        <translation>Klikoni mbi aplikacionin që doni të përfundohet</translation>
    </message>
</context>
<context>
    <name>Process.Graph.Title</name>
    <message>
        <source>Memory</source>
        <translation>Kujtesë</translation>
    </message>
    <message>
        <source>Receive</source>
        <translation>Marrje</translation>
    </message>
</context>
<context>
    <name>Process.Graph.View</name>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Lexim në disk</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Shkrim në disk</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Kujtesë</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Swap</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>I paaktivizuar</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Shkarkim</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Ngarkim</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Rrjet</translation>
    </message>
    <message>
        <source>Total Received</source>
        <translation>Të marrë gjithsej</translation>
    </message>
    <message>
        <source>Total Sent</source>
        <translation>Të dërguar gjithsej</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Dërgim</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Disqe</translation>
    </message>
</context>
<context>
    <name>Process.Loading</name>
    <message>
        <source>Loading</source>
        <translation>Po ngarkohet</translation>
    </message>
</context>
<context>
    <name>Process.Priority</name>
    <message>
        <source>Very high</source>
        <translation>Shumë e lartë</translation>
    </message>
    <message>
        <source>High</source>
        <translation>E lartë</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normale</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>E ulët</translation>
    </message>
    <message>
        <source>Very low</source>
        <translation>Shumë e ulët</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Vetjake</translation>
    </message>
    <message>
        <source>Invalid</source>
        <translation>E pavlefshme</translation>
    </message>
    <message>
        <source>PID: %1, Error: [%2] %3</source>
        <translation>PID: %1, Gabim: [%2] %3</translation>
    </message>
    <message>
        <source>Failed to change process priority</source>
        <translation>S’u arrit të ndryshohet përparësi procesi</translation>
    </message>
</context>
<context>
    <name>Process.Show.Mode</name>
    <message>
        <source>Applications</source>
        <translation>Aplikacione</translation>
    </message>
    <message>
        <source>My processes</source>
        <translation>Proceset e mia</translation>
    </message>
    <message>
        <source>All processes</source>
        <translation>Krejt proceset</translation>
    </message>
</context>
<context>
    <name>Process.Signal</name>
    <message>
        <source>Failed to pause process</source>
        <translation>S’u arrit të pushohej procesi</translation>
    </message>
    <message>
        <source>Failed to resume process</source>
        <translation>S’u arrit të rimerrej procesi</translation>
    </message>
    <message>
        <source>Failed to kill process</source>
        <translation>S’u arrit të asgjësohej procesi</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Gabim i panjohur</translation>
    </message>
    <message>
        <source>Failed in sending signal to process</source>
        <translation>S’u arrit t’i dërgohej sinjal procesit</translation>
    </message>
    <message>
        <source>Failed to end process</source>
        <translation>S’u arrit të përfundohej procesi</translation>
    </message>
</context>
<context>
    <name>Process.Summary</name>
    <message>
        <source>(%1 applications and %2 processes are running)</source>
        <translation>(Janë në punë %1 aplikacione dhe %2 procese)</translation>
    </message>
</context>
<context>
    <name>Process.Table</name>
    <message>
        <source>No response</source>
        <translation>S’ka përgjigje</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Pezulloje</translation>
    </message>
    <message>
        <source>Tray</source>
        <translation>Panel</translation>
    </message>
</context>
<context>
    <name>Process.Table.Context.Menu</name>
    <message>
        <source>View command location</source>
        <translation>Shihni vendndodhje urdhri</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Veti</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>Përfundoje procesin</translation>
    </message>
    <message>
        <source>Resume process</source>
        <translation>Rimerre procesin</translation>
    </message>
    <message>
        <source>Kill process</source>
        <translation>Asgjësoje procesin</translation>
    </message>
    <message>
        <source>Change priority</source>
        <translation>Ndryshojini përparësinë</translation>
    </message>
    <message>
        <source>Suspend process</source>
        <translation>Pezulloje procesin</translation>
    </message>
</context>
<context>
    <name>Process.Table.Custom.Priority.Dialog</name>
    <message>
        <source>Custom Priority</source>
        <translation>Përparësi Vetjake</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuloje</translation>
    </message>
    <message>
        <source>Change</source>
        <comment>button</comment>
        <translation>Ndryshoje</translation>
    </message>
</context>
<context>
    <name>Process.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>Emër</translation>
    </message>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Kujtesë</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Shkrim në disk</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Lexim në disk</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Shkarkim</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Ngarkim</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Përdorues</translation>
    </message>
    <message>
        <source>Nice</source>
        <translation>Nice</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Përparësi</translation>
    </message>
    <message>
        <source>Shared memory</source>
        <translation>Kujtesë e përbashkët</translation>
    </message>
    <message>
        <source>Virtual memory</source>
        <translation>Kujtesë virtuale</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Not support</source>
        <translation>Pa mbulim</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Rregullime</translation>
    </message>
    <message>
        <source>System Protection</source>
        <translation>Mbrojtje Sistemi</translation>
    </message>
    <message>
        <source>Show warnings when the usage exceeds the thresholds</source>
        <translation>Shfaq sinjalizime, kur përdorimi tejkalon pragjet</translation>
    </message>
    <message>
        <source>CPU warning threshold (%)</source>
        <translation>Prag sinjalizimi për CPU-në (%)</translation>
    </message>
    <message>
        <source>Memory warning threshold (%)</source>
        <translation>Prag sinjalizimi për kujtesën (%)</translation>
    </message>
    <message>
        <source>Warning interval (min)</source>
        <translation>Interval sinjalizimi (min)</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Njoftime</translation>
    </message>
</context>
<context>
    <name>Service.Action.Set.Startup.Mode</name>
    <message>
        <source>Failed to set service startup type</source>
        <translation>S’u arrit të caktohej lloj nisjeje shërbimi</translation>
    </message>
    <message>
        <source>Error: Failed to set service startup type due to the crashed sub process.</source>
        <translation>Gabim: S’u arrit të caktohej lloj nisjeje shërbimi, për shkak të një nënprocesi të vithisur.</translation>
    </message>
</context>
<context>
    <name>Service.Instance.Name.Dialog</name>
    <message>
        <source>Service instance name</source>
        <translation>Emër instance shërbimi</translation>
    </message>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
</context>
<context>
    <name>Service.Table.Context.Menu</name>
    <message>
        <source>Refresh</source>
        <translation>Rifreskoje</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Nise</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Ndale</translation>
    </message>
    <message>
        <source>Restart</source>
        <translation>Rinise</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Dorazi</translation>
    </message>
    <message>
        <source>Startup type</source>
        <translation>Lloj nisjeje</translation>
    </message>
</context>
<context>
    <name>Service.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>Emër</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Ngarkoje</translation>
    </message>
    <message>
        <source>Active</source>
        <translation type="vanished">Aktiv</translation>
    </message>
    <message>
        <source>Sub</source>
        <translation>Sub</translation>
    </message>
    <message>
        <source>State</source>
        <translation type="vanished">Gjendje</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Përshkrim</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Startup Type</source>
        <translation>Lloj Nisjeje</translation>
    </message>
    <message>
        <source>Start State</source>
        <translation>Përlancëzimi i pozicionit</translation>
    </message>
    <message>
        <source>Start Tactic</source>
        <translation>Metoda e përlancëzimit</translation>
    </message>
</context>
<context>
    <name>SystemProtectionSetting</name>
    <message>
        <source>Settings</source>
        <translation>Rregullime</translation>
    </message>
    <message>
        <source>(Modifiable)</source>
        <translation>(I ndryshueshëm)</translation>
    </message>
    <message>
        <source>Range: %1-%2</source>
        <translation>Interval: %1-%2</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Context.Menu</name>
    <message>
        <source>Force end application</source>
        <translation>Detyro përfundim aplikacioni</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Zgjeroje</translation>
    </message>
    <message>
        <source>Compact</source>
        <translation>Mblidhe</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Shihni</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Search</name>
    <message>
        <source>Search</source>
        <translation>Kërko</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Switch</name>
    <message>
        <source>Processes</source>
        <translation>Procese</translation>
    </message>
    <message>
        <source>Services</source>
        <translation>Shërbime</translation>
    </message>
    <message>
        <source>Users</source>
        <translation>Përdorues</translation>
    </message>
</context>
<context>
    <name>User.Account.Type</name>
    <message>
        <source>Administrator</source>
        <translation>Përgjegjës</translation>
    </message>
    <message>
        <source>Standard User</source>
        <translation>Përdorues Standard</translation>
    </message>
</context>
<context>
    <name>User.Account.Operation</name>
    <message>
        <source>Edit account information</source>
        <translation>Përpunoni hollësi llogarie</translation>
    </message>
</context>
</TS>